@@ -3,34 +3,36 @@ from rath.operation import GraphQLResult, Operation
 
 
 class Link:
-    def connect(self) -> None:
+    async def __aenter__(self) -> None:
         pass
 
-    def disconnect(self) -> None:
+    async def __aexit__(self, *args, **kwargs) -> None:
         pass
 
-    async def aconnect(self) -> None:
+    def __enter__(self) -> None:
         pass
 
-    async def adisconnect(self) -> None:
+    def __exit__(self, *args, **kwargs) -> None:
         pass
 
-    async def aquery(self, operation: Operation) -> GraphQLResult:
+    async def aquery(self, operation: Operation, **kwargs) -> GraphQLResult:
         raise NotImplementedError(
             f"Please overwrite the aquery method in {self.__class__.__name__}"
         )
 
-    async def asubscribe(self, operation: Operation) -> AsyncIterator[GraphQLResult]:
+    async def asubscribe(
+        self, operation: Operation, **kwargs
+    ) -> AsyncIterator[GraphQLResult]:
         raise NotImplementedError(
             f"Please overwrite the asubscribe method in {self.__class__.__name__}"
         )
 
-    def query(self, operation: Operation) -> GraphQLResult:
+    def query(self, operation: Operation, **kwargs) -> GraphQLResult:
         raise NotImplementedError(
             f"Please overwrite the query method in {self.__class__.__name__}"
         )
 
-    def subscribe(self, operation: Operation) -> Iterator[GraphQLResult]:
+    def subscribe(self, operation: Operation, **kwargs) -> Iterator[GraphQLResult]:
         raise NotImplementedError(
             f"Please overwrite the subscribe method in {self.__class__.__name__}"
         )
@@ -41,16 +43,16 @@ class TerminatingLink(Link):
         self.rath = rath
         return self
 
-    async def aconnect(self) -> None:
+    async def __aenter__(self) -> None:
         pass
 
-    async def adisconnect(self) -> None:
+    async def __aexit__(self, *args, **kwargs) -> None:
         pass
 
-    def connect(self) -> None:
+    def __enter__(self) -> None:
         pass
 
-    def disconnect(self) -> None:
+    def __exit__(self, *args, **kwargs) -> None:
         pass
 
 
@@ -84,17 +86,30 @@ class ContinuationLink(Link):
         self.next = next
         return self
 
-    async def aconnect(self) -> None:
-        await self.next.aconnect()
+    async def aquery(self, operation: Operation, **kwargs) -> GraphQLResult:
+        return await self.next.aquery(operation, **kwargs)
 
-    async def adisconnect(self) -> None:
-        await self.next.adisconnect()
+    async def asubscribe(self, operation: Operation, **kwargs) -> GraphQLResult:
+        async for x in self.next.asubscribe(operation, **kwargs):
+            yield x
 
-    def connect(self) -> None:
-        self.next.connect()
+    def query(self, operation: Operation, **kwargs) -> GraphQLResult:
+        return self.next.query(operation, **kwargs)
 
-    def disconnect(self) -> None:
-        self.next.disconnect()
+    def subscribe(self, operation: Operation, **kwargs) -> GraphQLResult:
+        return self.next.subscribe(operation, **kwargs)
+
+    async def __aenter__(self) -> None:
+        return await self.next.__aenter__()
+
+    async def __aexit__(self, *args, **kwargs) -> None:
+        return await self.next.__aexit__(*args, **kwargs)
+
+    def __enter__(self) -> None:
+        self.next.__enter__()
+
+    def __exit__(self, *args, **kwargs) -> None:
+        self.next.__exit__(*args, **kwargs)
 
 
 class AsyncContinuationLink(ContinuationLink):
