@@ -39,18 +39,6 @@ class Rath:
         if register:
             set_current_rath(self)
 
-    def connect(self):
-        self.link.connect()
-
-    def disconnect(self):
-        self.link.disconnect()
-
-    async def aconnect(self):
-        await self.link.aconnect()
-
-    async def adisconnect(self):
-        await self.link.adisconnect()
-
     async def aexecute(
         self,
         query: str,
@@ -66,9 +54,7 @@ class Rath:
         if timeout:
             return await asyncio.wait_for(self.link.aquery(op), timeout)
 
-        return await self.link.aquery(
-            op,
-        )
+        return await self.link.aquery(op, **kwargs)
 
     def execute(
         self,
@@ -80,9 +66,7 @@ class Rath:
     ) -> GraphQLResult:
         op = opify(query, variables, headers, operation_name, **kwargs)
 
-        return self.link.query(
-            op,
-        )
+        return self.link.query(op, **kwargs)
 
     def subscribe(
         self,
@@ -94,8 +78,8 @@ class Rath:
     ) -> Iterator[GraphQLResult]:
 
         op = opify(query, variables, headers, operation_name, **kwargs)
-        for res in self.link.subscribe(op):
-            yield res
+        print("subscribe here")
+        return self.link.subscribe(op, **kwargs)
 
     async def asubscribe(
         self,
@@ -107,22 +91,28 @@ class Rath:
     ) -> AsyncIterator[GraphQLResult]:
 
         op = opify(query, variables, headers, operation_name, **kwargs)
-        async for res in self.link.asubscribe(op):
+        async for res in self.link.asubscribe(op, **kwargs):
             yield res
 
     async def __aenter__(self):
-        await self.aconnect()
+        await self.link.__aenter__()
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        await self.adisconnect()
+        await self.link.__aexit__(exc_type, exc_val, exc_tb)
 
     def __enter__(self):
-        self.connect()
+        self.link.__enter__()
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.disconnect()
+        self.link.__exit__(exc_type, exc_val, exc_tb)
+
+    def connect(self):
+        return self.__enter__()
+
+    def disconnect(self):
+        return self.__exit__(None, None, None)
 
 
 CURRENT_RATH = None
